@@ -8,10 +8,10 @@ into your kivy app.
 the generic class :class:`Tooltip` of this portion displays text blocks that are automatically positioned next to any
 widget to providing e.g. i18n context help texts or app tour/onboarding info.
 
-:class:`ModalBehavior` is another generic mix-in class that provides modal behavior to any container widget.
+:class:`ModalBehavior` is a generic mix-in class that provides modal behavior to any container widget.
 
 the mixin class :class:`HelpBehavior` provided by this namespace portion extends and prepares any Kivy widget to show an
-individual help text for it. the widget :class:`HelpToggler` is a toggle button to switch the help mode on and off.
+individual help text for it. the :class:`HelpToggler` toggle button widget switches the app's help mode on and off.
 
 the other classes of this portion are used to overlay or augment the app’s user interface with product tours, tutorials,
 walkthroughs and user onboarding/welcome features.
@@ -159,13 +159,21 @@ from ae.kivy_glsl import ShaderIdType, ShadersMixin
 from ae.kivy_relief_canvas import ReliefCanvas                                                          # type: ignore
 
 
-__version__ = '0.2.32'
+__version__ = '0.3.33'
 
 
 # load/declared help/tour widgets, based-on Kivy core widgets (without any features from ae.kivy_app/widgets.kv)
 Builder.load_file(os.path.join(os.path.dirname(__file__), "widgets.kv"))
 
 
+ANI_SINE_DEEPER_REPEAT3 = \
+    Animation(ani_value=0.99, t='in_out_sine', d=0.9) + Animation(ani_value=0.87, t='in_out_sine', d=1.2) + \
+    Animation(ani_value=0.96, t='in_out_sine', d=1.5) + Animation(ani_value=0.75, t='in_out_sine', d=1.2) + \
+    Animation(ani_value=0.90, t='in_out_sine', d=0.9) + Animation(ani_value=0.45, t='in_out_sine', d=0.6)
+""" sine 3 x deeper repeating animation, used e.g. to animate help layout (ae.kivy_help.Tooltip) """
+ANI_SINE_DEEPER_REPEAT3.repeat = True
+
+
 PosSizeCallable = Callable[[Widget, List[float]], Any]
 BoundWidgetPropertyId = Tuple[Widget, str, int]
 PropagatedAttributes = Tuple[Any, str, Optional[PosSizeCallable]]
@@ -182,15 +190,15 @@ class AbsolutePosSizeBinder:
         :param bind_window_size: pass True to propagate pos and size changes if window size changes.
         """
         self.widgets = widgets
-        self.relatives: List[Widget] = list()
+        self.relatives: List[Widget] = []
         self.main_app = App.get_running_app().main_app
 
-        self._pos_attributes: List[PropagatedAttributes] = list()
-        self._size_attributes: List[PropagatedAttributes] = list()
-        self._pos_callbacks: List[PosSizeCallable] = list()
-        self._size_callbacks: List[PosSizeCallable] = list()
-        self._bound_wid_properties: List[BoundWidgetPropertyId] = list()
-        self._bound_rel_properties: List[BoundWidgetPropertyId] = list()
+        self._pos_attributes: List[PropagatedAttributes] = []
+        self._size_attributes: List[PropagatedAttributes] = []
+        self._pos_callbacks: List[PosSizeCallable] = []
+        self._size_callbacks: List[PosSizeCallable] = []
+        self._bound_wid_properties: List[BoundWidgetPropertyId] = []
+        self._bound_rel_properties: List[BoundWidgetPropertyId] = []
 
         self._bind()
         if bind_window_size:
@@ -206,7 +214,7 @@ class AbsolutePosSizeBinder:
             self._bound_wid_properties.append((wid, 'size', uid))
 
             parent = wid.parent
-            while parent != parent.parent:
+            while parent and parent != parent.parent:
                 if isinstance(parent, (ScrollView, RelativeLayout)) and parent not in self.relatives:
                     uid = parent.fbind('pos', self._rel_pos_changed)
                     self._bound_rel_properties.append((parent, 'pos', uid))
@@ -332,7 +340,7 @@ class ModalBehavior:
     :attr:`auto_dismiss` is a :class:`~kivy.properties.BooleanProperty` and defaults to True.
     """
 
-    _fast_bound: List = list()                              #: list of arg tuples for fbind/funbind
+    _fast_bound: List = []                                  #: list of arg tuples for fbind/funbind
     _touch_started_inside: Optional[bool] = None            #: flag if touch started inside of the container widget
     _window = ObjectProperty(allownone=True, rebind=True)   #: internal flag to store main window instance if open
 
@@ -360,7 +368,7 @@ class ModalBehavior:
         fast_unbind = self.funbind                                              # pylint: disable=no-member
         for fast_unbinding in self._fast_bound:
             fast_unbind(*fast_unbinding)
-        self._fast_bound = list()
+        self._fast_bound = []
 
         if self._window:
             Window.unbind(on_resize=self._align_center, on_key_down=self._on_key_down)
@@ -395,7 +403,7 @@ class ModalBehavior:
     def on_touch_move(self, touch):
         """ touch move event handler. """
         if not self.auto_dismiss or self._touch_started_inside:
-            super().on_touch_move(touch)    # type: ignore # pylint: disable=no-member # false positive
+            super().on_touch_move(touch)    # pylint: disable=no-member # false positive
         return True
 
     def on_touch_up(self, touch):
@@ -403,7 +411,7 @@ class ModalBehavior:
         if self.auto_dismiss and self._touch_started_inside is False:
             self.close()
         else:
-            super().on_touch_up(touch)      # type: ignore # pylint: disable=no-member # false positive
+            super().on_touch_up(touch)      # pylint: disable=no-member # false positive
         self._touch_started_inside = None
         return True
 
@@ -567,12 +575,23 @@ class HelpToggler(ReliefCanvas, Image):
     * a :meth:`~HelpToggler.on_touch_down` method not passing a activation touch in all DropDown/Popup widgets.
 
     """
+    ani_value = NumericProperty(0.999)      #: float value (range: 0.0 - 1.0) to animate this button in help/tour mode
+
     def __init__(self, **kwargs):
         """ initialize an instance of this class and also :attr:`~ae.gui_help.HelpAppBase.help_activator`. """
         self.main_app = App.get_running_app().main_app
         self.main_app.help_activator = self
         super().__init__(**kwargs)
 
+    def ani_start(self):
+        """ start animation of this button. """
+        ANI_SINE_DEEPER_REPEAT3.start(self)
+
+    def ani_stop(self):
+        """ stop animation of this button. """
+        ANI_SINE_DEEPER_REPEAT3.stop(self)
+        self.ani_value = 0.999
+
     def on_touch_down(self, touch: MotionEvent) -> bool:
         """ touch down event handler to toggle help mode while preventing dismiss of open dropdowns/popups.
 
@@ -634,7 +653,7 @@ def animated_widget_values(wid: Widget, ani: Union[Animation, CompoundAnimation]
     :param ani:                 :class:`~kivy.animation.Animation`/:class:`kivy.animation.CompoundAnimation` instance.
     :return:                    dict with widget property names and values.
     """
-    wid_values = dict()
+    wid_values = {}
     for key in ani.animated_properties.keys():
         wid_values[key] = getattr(wid, key)
     return wid_values
@@ -662,18 +681,18 @@ class AnimatedTourMixin:        # (TourBase):
     def __init__(self, main_app: 'HelpAppBase') -> None:
         super().__init__(main_app)                                          # type: ignore # pylint: disable=no-member
 
-        self._added_animations: List[Tuple[Widget, Animation, WidgetValues]] = list()
-        self._added_shaders: List[Tuple[Widget, ShaderIdType]] = list()
+        self._added_animations: List[Tuple[Widget, Animation, WidgetValues]] = []
+        self._added_shaders: List[Tuple[Widget, ShaderIdType]] = []
         self._explained_binder = AbsolutePosSizeBinder()
 
-        self.pages_animations: Dict[Optional[str], PageAnimationsType] = dict()
+        self.pages_animations: Dict[Optional[str], PageAnimationsType] = {}
         """ dict of compound animation instances of the pages of this tour.
 
         the key of this dict is the page id or None (for animations available in all pages of this tour).
         each value of this dict is of the type :data:`PageAnimationsType`.
         """
 
-        self.pages_shaders: Dict[Optional[str], Tuple[Tuple[str, ShaderIdType], ...]] = dict()
+        self.pages_shaders: Dict[Optional[str], Tuple[Tuple[str, ShaderIdType], ...]] = {}
         """ dict of widget shaders for the pages of this tour.
 
         the key of this dict is the page id or None (for shaders available in all pages of this tour).
@@ -692,7 +711,7 @@ class AnimatedTourMixin:        # (TourBase):
         :class:`~kivy.clock.Clock`, :class:`~kivy.core.window.Window` and the `tour` instance.
         """
 
-        self.switch_next_animations: Dict[Optional[str], PageAnimationsType] = dict()
+        self.switch_next_animations: Dict[Optional[str], PageAnimationsType] = {}
         """ dict of compound animation instances for the next page switch transition of the pages of this tour.
 
         the key of this dict is the page id or None (for animations available in all pages of this tour).
@@ -707,7 +726,7 @@ class AnimatedTourMixin:        # (TourBase):
         """
         max_len = 0.0
         layout = self.layout
-        added = list()
+        added = []
         for wid_id, anim in animations:
             if isinstance(anim, str):
                 glo_vars = self.main_app.global_variables(layout=layout, sp=sp, tour=self,
@@ -777,7 +796,7 @@ class AnimatedTourMixin:        # (TourBase):
         page_id = self.page_ids[self.page_idx]
         page_shaders = self.pages_shaders.get(None, ()) + self.pages_shaders.get(page_id, ())
         layout = self.layout
-        added = list()
+        added = []
         for wid_id, shader_kwargs in page_shaders:
             wid = layout.ids.get(wid_id, layout) if wid_id else layout.explained_widget
             added.append((wid, wid.add_shader(**_evaluated_shader_kwargs())))
@@ -789,6 +808,7 @@ class AnimatedTourMixin:        # (TourBase):
         """ overridden to setup animations and shaders of the current tour page. """
         # noinspection PyUnresolvedReferences
         super().setup_layout()                                                              # pylint: disable=no-member
+        Clock.tick()                # update position of explained widget
         self.setup_page_shaders_and_animations()
 
     def simulate_text_input(self, text_input: TextInput, text_to_delay: str,
@@ -816,7 +836,7 @@ class AnimatedTourMixin:        # (TourBase):
 
     def tap_animation(self, wid_id: str = '', pos_delay: float = 2.34,
                       press_delay: float = 0.69, release_delay: float = 0.39) -> PageAnimationType:
-        """ create an compound animation instance simulating a user touch/tap on the widget with the passed widget id.
+        """ create an compound animation instance simulating a user touch/tap on the specified widget.
 
         :param wid_id:          specifies the widget to be tap simulated: either a widget id string (first item of the
                                 :data:`PageAnimationType` tuple), or (if prefixed with a column character) tap/focus/
@@ -867,11 +887,11 @@ class AnimatedTourMixin:        # (TourBase):
         for wid, anim, start_values in reversed(self._added_animations):
             anim.stop(wid)
             restore_widget_values(wid, start_values)
-        self._added_animations = list()
+        self._added_animations = []
 
         for wid, shader_id in reversed(self._added_shaders):
             wid.del_shader(shader_id)
-        self._added_shaders = list()
+        self._added_shaders = []
 
     def teardown_app_flow(self):
         """ overridden to teardown the animations of the current/last-shown tour page. """
@@ -1193,9 +1213,11 @@ class TourOverlay(ModalBehavior, ShadersMixin, FloatLayout):
             # noinspection PyArgumentList
             self.tour_instance = tour_instance = tour_cls(main_app)     # initialize tour instance
             tour_instance.start()                                       # start tour
+            main_app.help_activator.ani_start()
         except Exception as ex:
             main_app.po(f"TourOverlay.start_tour exception {ex}")
             traceback.print_exc()
+            main_app.help_activator.ani_stop()
             main_app.change_observable('tour_layout', None)             # reset tour layout
             return False
 
@@ -1223,6 +1245,7 @@ class TourOverlay(ModalBehavior, ShadersMixin, FloatLayout):
         else:
             main_app.po("TourOverlay.stop_tour error: called without tour instance")
 
+        main_app.help_activator.ani_stop()
         main_app.change_observable('tour_layout', None)    # set app./main_app.tour_layout to None
 
         self.deactivate_modal()
